@@ -43,7 +43,7 @@ FTDI_SENSOR_CLASSES = [
 UART_SENSOR_CLASSES = [SPS30, SMGair2, S8000]
 
 
-def scan_spi(spibus, loglvl: int = logging.ERROR, measurement_obj=None):
+def scan_spi(spibus, loglvl: int = logging.ERROR, **kwargs):
     if type(spibus) is SpiController:
         spibus = [spibus]
     elif type(spibus) is not list:
