@@ -94,7 +94,7 @@ if __name__ == "__main__":
     hdl = log.handlers[0].setFormatter(logging.Formatter(fmt))
     Bus = []
     setups = []
-    CS_MUX = True
+    CS_MUX = False
 
     # Check how many serial converters are connected
     supported_converters = [(0x0403, 0x6014)]
@@ -112,7 +112,6 @@ if __name__ == "__main__":
 
     for t in threads:
         setups.append(t.join())
-
     threads = []
     if len(setups) > 0:
         for s in setups:
